<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>GuidelineEditDialog</name>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
        <source>Edit guideline...</source>
        <translation>Ustaw położenie prowadnicy…</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
        <source>Page:</source>
        <translation>Strona:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
        <source>Position:</source>
        <translation>Pozycja:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="59"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="64"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="69"/>
        <source>bp</source>
        <translation>bp</translation>
    </message>
</context>
<context>
    <name>PaperSize</name>
    <message>
        <location filename="../src/PaperSizes.cpp" line="24"/>
        <source>Beamer 16:10</source>
        <translation>Beamer 16:10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="25"/>
        <source>Beamer 16:9</source>
        <translation>Beamer 16:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="26"/>
        <source>Beamer 14:9</source>
        <translation>Beamer 14:9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="27"/>
        <source>Beamer 1.41:1</source>
        <translation>Beamer 1.41:1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="28"/>
        <source>Beamer 5:4</source>
        <translation>Beamer 5:4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="29"/>
        <source>Beamer 4:3</source>
        <translation>Beamer 4:3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="30"/>
        <source>Beamer 3:2</source>
        <translation>Beamer 3:2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="33"/>
        <source>Screen</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="36"/>
        <source>DIN 4A0</source>
        <translation>DIN 4A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="37"/>
        <source>DIN 2A0</source>
        <translation>DIN 2A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="38"/>
        <source>DIN A0</source>
        <translation>DIN A0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="39"/>
        <source>DIN A1</source>
        <translation>DIN A1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="40"/>
        <source>DIN A2</source>
        <translation>DIN A2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="41"/>
        <source>DIN A3</source>
        <translation>DIN A3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="42"/>
        <source>DIN A4</source>
        <translation>DIN A4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="43"/>
        <source>DIN A5</source>
        <translation>DIN A5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="44"/>
        <source>DIN A6</source>
        <translation>DIN A6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="45"/>
        <source>DIN A7</source>
        <translation>DIN A7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="46"/>
        <source>DIN A8</source>
        <translation>DIN A8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="47"/>
        <source>DIN A9</source>
        <translation>DIN A9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="48"/>
        <source>DIN A10</source>
        <translation>DIN A10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="49"/>
        <source>DIN B0</source>
        <translation>DIN B0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="50"/>
        <source>DIN B1</source>
        <translation>DIN B1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="51"/>
        <source>DIN B2</source>
        <translation>DIN B2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="52"/>
        <source>DIN B3</source>
        <translation>DIN B3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="53"/>
        <source>DIN B4</source>
        <translation>DIN B4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="54"/>
        <source>DIN B5</source>
        <translation>DIN B5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="55"/>
        <source>DIN B6</source>
        <translation>DIN B6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="56"/>
        <source>DIN B7</source>
        <translation>DIN B7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="57"/>
        <source>DIN B8</source>
        <translation>DIN B8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="58"/>
        <source>DIN B9</source>
        <translation>DIN B9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="59"/>
        <source>DIN B10</source>
        <translation>DIN B10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="60"/>
        <source>DIN C0</source>
        <translation>DIN C0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="61"/>
        <source>DIN C1</source>
        <translation>DIN C1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="62"/>
        <source>DIN C2</source>
        <translation>DIN C2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="63"/>
        <source>DIN C3</source>
        <translation>DIN C3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="64"/>
        <source>DIN C4</source>
        <translation>DIN C4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="65"/>
        <source>DIN C5</source>
        <translation>DIN C5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="66"/>
        <source>DIN C6</source>
        <translation>DIN C6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="67"/>
        <source>DIN C7</source>
        <translation>DIN C7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="68"/>
        <source>DIN C8</source>
        <translation>DIN C8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="69"/>
        <source>DIN C9</source>
        <translation>DIN C9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="70"/>
        <source>DIN C10</source>
        <translation>DIN C10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="71"/>
        <source>DIN DL</source>
        <translation>DIN DL</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="72"/>
        <source>DIN DLE</source>
        <translation>DIN DLE</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="73"/>
        <source>DIN C6/C5</source>
        <translation>DIN C6/C5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="74"/>
        <source>DIN RA0</source>
        <translation>DIN RA0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="75"/>
        <source>DIN RA1</source>
        <translation>DIN RA1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="76"/>
        <source>DIN RA2</source>
        <translation>DIN RA2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="77"/>
        <source>DIN RA3</source>
        <translation>DIN RA3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="78"/>
        <source>DIN RA4</source>
        <translation>DIN RA4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="79"/>
        <source>DIN SRA0</source>
        <translation>DIN SRA0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="80"/>
        <source>DIN SRA1</source>
        <translation>DIN SRA1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="81"/>
        <source>DIN SRA2</source>
        <translation>DIN SRA2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="82"/>
        <source>DIN SRA3</source>
        <translation>DIN SRA3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="83"/>
        <source>DIN SRA4</source>
        <translation>DIN SRA4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="84"/>
        <source>SIS D0</source>
        <translation>SIS D0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="85"/>
        <source>SIS D1</source>
        <translation>SIS D1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="86"/>
        <source>SIS D2</source>
        <translation>SIS D2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="87"/>
        <source>SIS D3</source>
        <translation>SIS D3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="88"/>
        <source>SIS D4</source>
        <translation>SIS D4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="89"/>
        <source>SIS D5</source>
        <translation>SIS D5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="90"/>
        <source>SIS D6</source>
        <translation>SIS D6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="91"/>
        <source>SIS D7</source>
        <translation>SIS D7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="92"/>
        <source>SIS D8</source>
        <translation>SIS D8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="93"/>
        <source>SIS D9</source>
        <translation>SIS D9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="94"/>
        <source>SIS E0</source>
        <translation>SIS E0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="95"/>
        <source>SIS E1</source>
        <translation>SIS E1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="96"/>
        <source>SIS E2</source>
        <translation>SIS E2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="97"/>
        <source>SIS E3</source>
        <translation>SIS E3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="98"/>
        <source>SIS E4</source>
        <translation>SIS E4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="99"/>
        <source>SIS E5</source>
        <translation>SIS E5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="100"/>
        <source>SIS E6</source>
        <translation>SIS E6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="101"/>
        <source>SIS E7</source>
        <translation>SIS E7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="102"/>
        <source>SIS E8</source>
        <translation>SIS E8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="103"/>
        <source>SIS E9</source>
        <translation>SIS E9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="104"/>
        <source>SIS F0</source>
        <translation>SIS F0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="105"/>
        <source>SIS F1</source>
        <translation>SIS F1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="106"/>
        <source>SIS F2</source>
        <translation>SIS F2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="107"/>
        <source>SIS F3</source>
        <translation>SIS F3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="108"/>
        <source>SIS F4</source>
        <translation>SIS F4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="109"/>
        <source>SIS F5</source>
        <translation>SIS F5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="110"/>
        <source>SIS F6</source>
        <translation>SIS F6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="111"/>
        <source>SIS F7</source>
        <translation>SIS F7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="112"/>
        <source>SIS F8</source>
        <translation>SIS F8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="113"/>
        <source>SIS F9</source>
        <translation>SIS F9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="114"/>
        <source>SIS G0</source>
        <translation>SIS G0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="115"/>
        <source>SIS G1</source>
        <translation>SIS G1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="116"/>
        <source>SIS G2</source>
        <translation>SIS G2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="117"/>
        <source>SIS G3</source>
        <translation>SIS G3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="118"/>
        <source>SIS G4</source>
        <translation>SIS G3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="119"/>
        <source>SIS G5</source>
        <translation>SIS G5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="120"/>
        <source>SIS G6</source>
        <translation>SIS G6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="121"/>
        <source>SIS G7</source>
        <translation>SIS G7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="122"/>
        <source>SIS G8</source>
        <translation>SIS G8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="123"/>
        <source>SIS G9</source>
        <translation>SIS G9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="124"/>
        <source>JIS B0</source>
        <translation>JIS B0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="125"/>
        <source>JIS B1</source>
        <translation>JIS B1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="126"/>
        <source>JIS B2</source>
        <translation>JIS B2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="127"/>
        <source>JIS B3</source>
        <translation>JIS B3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="128"/>
        <source>JIS B4</source>
        <translation>JIS B4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="129"/>
        <source>JIS B5</source>
        <translation>JIS B5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="130"/>
        <source>JIS B6</source>
        <translation>JIS B6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="131"/>
        <source>JIS B7</source>
        <translation>JIS B7</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="132"/>
        <source>JIS B8</source>
        <translation>JIS B8</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="133"/>
        <source>JIS B9</source>
        <translation>JIS B9</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="134"/>
        <source>JIS B10</source>
        <translation>JIS B10</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="135"/>
        <source>JIS B11</source>
        <translation>JIS B11</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="136"/>
        <source>JIS B12</source>
        <translation>JIS B12</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="137"/>
        <source>JIS Shiroku ban 4</source>
        <translation>JIS Shiroku ban 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="138"/>
        <source>JIS Shiroku ban 5</source>
        <translation>JIS Shiroku ban 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="139"/>
        <source>JIS Shiroku ban 6</source>
        <translation>JIS Shiroku ban 6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="140"/>
        <source>JIS Kiku 4</source>
        <translation>JIS Kiku 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="141"/>
        <source>JIS Kiku 5</source>
        <translation>JIS Kiku 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="142"/>
        <source>SAC D0</source>
        <translation>SAC D0</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="143"/>
        <source>SAC D1</source>
        <translation>SAC D1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="144"/>
        <source>SAC D2</source>
        <translation>SAC D2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="145"/>
        <source>SAC D3</source>
        <translation>SAC D3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="146"/>
        <source>SAC D4</source>
        <translation>SAC D4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="147"/>
        <source>SAC D5</source>
        <translation>SAC D5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="148"/>
        <source>SAC D6</source>
        <translation>SAC D6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="150"/>
        <source>Letter (ANSI A)</source>
        <translation>Letter (ANSI A)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="151"/>
        <source>Legal</source>
        <translation>Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="152"/>
        <source>Tabloid (ANSI B)</source>
        <translation>Tabloid (ANSI B)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="153"/>
        <source>Ledger</source>
        <translation>Ledger</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="154"/>
        <source>Junior Legal</source>
        <translation>Junior Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="155"/>
        <source>Half Letter</source>
        <translation>Half Letter</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="156"/>
        <source>Government Letter</source>
        <translation>Government Letter</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="157"/>
        <source>Government Legal</source>
        <translation>Government Legal</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="158"/>
        <source>ANSI C</source>
        <translation>ANSI C</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="159"/>
        <source>ANSI D</source>
        <translation>ANSI D</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="160"/>
        <source>ANSI E</source>
        <translation>ANSI D</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="161"/>
        <source>Arch A</source>
        <translation>Arch A</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="162"/>
        <source>Arch B</source>
        <translation>Arch B</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="163"/>
        <source>Arch C</source>
        <translation>Arch C</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="164"/>
        <source>Arch D</source>
        <translation>Arch D</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="165"/>
        <source>Arch E1</source>
        <translation>Arch E1</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="166"/>
        <source>Arch E</source>
        <translation>Arch E</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="167"/>
        <source>Arch E2</source>
        <translation>Arch E2</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="168"/>
        <source>Arch E3</source>
        <translation>Arch E3</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="201"/>
        <source>mm</source>
        <extracomment>Length unit: millimeters</extracomment>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="207"/>
        <source>in</source>
        <extracomment>Length unit: inches</extracomment>
        <translation>in</translation>
    </message>
</context>
<context>
    <name>QtPDF</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="34"/>
        <source>[language name]</source>
        <translation>Polskie</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="35"/>
        <source>[translator&apos;s name/email]</source>
        <translation>Wojciech Myszka (myszka@norka.eu.org)</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <location filename="../src/PDFBackend.cpp" line="321"/>
        <source>rendering page</source>
        <translation>renderowanie strony</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="243"/>
        <source>Unlock PDF</source>
        <translation>Odblokuj PDF</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="243"/>
        <source>Please enter the password to unlock the PDF</source>
        <translation>Wprowadź hasło do odblokowania pliku PDF</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="259"/>
        <source>Incorrect password</source>
        <translation>Nieprawidłowe hasło</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="259"/>
        <source>The password you entered was incorrect.</source>
        <translation>Hasło, które wprowadziłeś jest nieprawidłowe.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="265"/>
        <source>This document is locked. You need a password to open it.</source>
        <translation>Dokument jest zablokowany. Potrzebne hasło, aby odblokować.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentScene.cpp" line="266"/>
        <source>Unlock</source>
        <translation>Odblokuj</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
        <source>Insufficient permission</source>
        <translation>Niewystarczające uprawnienia</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="978"/>
        <source>Text extraction is not allowed for this document.</source>
        <translation>Nie można skopiować tekstu z tego dokumentu.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2264"/>
        <source>Goto page %1</source>
        <translation>Przejdź do strony %1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2276"/>
        <source>Execute `%1`</source>
        <translation>Wykonaj %1</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2541"/>
        <source>Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="48"/>
        <location filename="../src/InfoWidgets.cpp" line="65"/>
        <source>Table of Contents</source>
        <translation>Spis treści</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="157"/>
        <location filename="../src/InfoWidgets.cpp" line="364"/>
        <source>Meta Data</source>
        <translation>Metadane</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="213"/>
        <location filename="../src/InfoWidgets.cpp" line="374"/>
        <source>Processing</source>
        <translation>Tworzenie</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="245"/>
        <location filename="../src/InfoWidgets.cpp" line="381"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="270"/>
        <source>B</source>
        <extracomment>File size: bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="272"/>
        <source>kB</source>
        <extracomment>File size: kilobytes</extracomment>
        <translation>kB</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="274"/>
        <source>MB</source>
        <extracomment>File size: megabytes</extracomment>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="276"/>
        <source>GB</source>
        <extracomment>File size: gigabytes</extracomment>
        <translation>GB</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="278"/>
        <source>TB</source>
        <extracomment>File size: terabytes</extracomment>
        <translation>TB</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="308"/>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="311"/>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="314"/>
        <location filename="../src/InfoWidgets.cpp" line="351"/>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="366"/>
        <source>Document</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="367"/>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="368"/>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="369"/>
        <source>Subject:</source>
        <translation>Temat:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="370"/>
        <source>Keywords:</source>
        <translation>Słowa kluczowe:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="371"/>
        <source>Page size:</source>
        <translation>Rozmiar strony:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="372"/>
        <source>File size:</source>
        <translation>Rozmiar pliku:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="375"/>
        <source>Creator:</source>
        <translatorcomment>taken from evince</translatorcomment>
        <translation>Twórca:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="376"/>
        <source>Producer:</source>
        <translatorcomment>taken from evince</translatorcomment>
        <translation>Producent:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="377"/>
        <source>Creation date:</source>
        <translation>Data utworzenia:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="378"/>
        <source>Modification date:</source>
        <translation>Data modyfikacji:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="379"/>
        <source>Trapped:</source>
        <translatorcomment>after wiki: https://pl.wikipedia.org/wiki/Trapping_(grafika)</translatorcomment>
        <translation>Zalewki:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="390"/>
        <location filename="../src/InfoWidgets.cpp" line="484"/>
        <source>Fonts</source>
        <translation>Czcionki</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="440"/>
        <source>Type 0</source>
        <translation>Type 0</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="443"/>
        <source>Type 1</source>
        <translation>Type 1</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="446"/>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (multiple master)</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="449"/>
        <source>Type 3</source>
        <translation>Type 3</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="452"/>
        <source>TrueType</source>
        <translation>TrueType</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="455"/>
        <source>yes</source>
        <translation>tak</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="455"/>
        <source>no</source>
        <translation>nie</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="458"/>
        <source>[embedded]</source>
        <translation>[osadzony]</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="461"/>
        <source>[builtin]</source>
        <translation>[wbudowany]</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Subset</source>
        <translation>Podzbiór</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="485"/>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="493"/>
        <location filename="../src/InfoWidgets.cpp" line="588"/>
        <source>Permissions</source>
        <translation>Uprawnienia</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="542"/>
        <location filename="../src/InfoWidgets.cpp" line="551"/>
        <location filename="../src/InfoWidgets.cpp" line="560"/>
        <location filename="../src/InfoWidgets.cpp" line="567"/>
        <location filename="../src/InfoWidgets.cpp" line="572"/>
        <source>Allowed</source>
        <translation>Dozwolone</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="544"/>
        <source>Low resolution only</source>
        <translation>Tylko w niskiej rozdzielczość</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="547"/>
        <location filename="../src/InfoWidgets.cpp" line="557"/>
        <location filename="../src/InfoWidgets.cpp" line="564"/>
        <location filename="../src/InfoWidgets.cpp" line="569"/>
        <location filename="../src/InfoWidgets.cpp" line="574"/>
        <location filename="../src/InfoWidgets.cpp" line="579"/>
        <location filename="../src/InfoWidgets.cpp" line="580"/>
        <location filename="../src/InfoWidgets.cpp" line="581"/>
        <location filename="../src/InfoWidgets.cpp" line="582"/>
        <location filename="../src/InfoWidgets.cpp" line="583"/>
        <source>Denied</source>
        <translation>Zabroniony</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="553"/>
        <source>Assembling only</source>
        <translation>Tylko łączenie</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="554"/>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>Wstawianie, obracanie lub kasowanie stron oraz dodawanie zakładek lub miniatur stron</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="562"/>
        <source>Accessibility support only</source>
        <translation>Kopiowanie zawartości (tylko udogodnienia dla niepełnosprawnych)</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="590"/>
        <source>Printing:</source>
        <translation>Drukowanie:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="591"/>
        <source>Modifications:</source>
        <translation>Modyfikowanie:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="592"/>
        <source>Extraction:</source>
        <translation>Wyodrębnianie:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="593"/>
        <source>Annotation:</source>
        <translation>Komentowanie:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="594"/>
        <source>Filling forms:</source>
        <translation>Wypełnianie pól formularzy:</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="602"/>
        <location filename="../src/InfoWidgets.cpp" line="694"/>
        <source>Annotations</source>
        <translation>Komentarze</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Page</source>
        <translation>Strona</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Subject</source>
        <translation>Temat</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="../src/InfoWidgets.cpp" line="695"/>
        <source>Contents</source>
        <translation>Zawartość</translation>
    </message>
</context>
</TS>
